==> haskell-skylighting-format-latex-0.1-173-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-skylighting-format-latex.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 skylighting-format-latex
version:              0.1
visibility:           public
id:                   skylighting-format-latex-0.1-EWga8W0uXS58IDpDvq75dE
key:                  skylighting-format-latex-0.1-EWga8W0uXS58IDpDvq75dE
license:              BSD-3-Clause
copyright:            (C) 2016-2022 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/skylighting
synopsis:             LaTeX formatter for skylighting syntax highlighting library
description:
    This module allows tokens produced by skylighting-core
    to be rendered as LaTeX macros.

category:             Text
abi:                  8fb7a833e1308da550ec3055cf01c9d3
exposed:              True
exposed-modules:      Skylighting.Format.LaTeX
import-dirs:          /usr/lib/ghc-9.4.8/site-local/skylighting-format-latex-0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/skylighting-format-latex-0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/skylighting-format-latex-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting-format-latex
hs-libraries:         HSskylighting-format-latex-0.1-EWga8W0uXS58IDpDvq75dE
depends:
    base-4.17.2.1 containers-0.6.7
    skylighting-core-0.14.1.1-HHzHXtDQWpv2EmdaAgf3SZ text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-skylighting-format-latex/html/skylighting-format-latex.haddock

haddock-html:         /usr/share/doc/haskell-skylighting-format-latex/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-skylighting-format-latex-0.1-174-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-skylighting-format-latex.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 skylighting-format-latex
version:              0.1
visibility:           public
id:                   skylighting-format-latex-0.1-9AZgKy5jHB7LQ5dduCc5oP
key:                  skylighting-format-latex-0.1-9AZgKy5jHB7LQ5dduCc5oP
license:              BSD-3-Clause
copyright:            (C) 2016-2022 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/skylighting
synopsis:             LaTeX formatter for skylighting syntax highlighting library
description:
    This module allows tokens produced by skylighting-core
    to be rendered as LaTeX macros.

category:             Text
abi:                  63f8e5f9043103ba0e6aebb110e9ed1b
exposed:              True
exposed-modules:      Skylighting.Format.LaTeX
import-dirs:          /usr/lib/ghc-9.4.8/site-local/skylighting-format-latex-0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/skylighting-format-latex-0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/skylighting-format-latex-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting-format-latex
hs-libraries:         HSskylighting-format-latex-0.1-9AZgKy5jHB7LQ5dduCc5oP
depends:
    base-4.17.2.1 containers-0.6.7
    skylighting-core-0.14.1.1-F82pHvR2PHWFgExKSmYbkG text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-skylighting-format-latex/html/skylighting-format-latex.haddock

haddock-html:         /usr/share/doc/haskell-skylighting-format-latex/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
